"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _jayson = _interopRequireDefault(require("jayson"));

var _eslint = require("eslint");

var _cliUtils = require("./cliUtils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class Client {
  constructor(options) {
    this.options = options;
    this.eslint = new _eslint.ESLint();
  }

  async connect() {
    const {
      port,
      formatter,
      maxWarnings
    } = this.options;

    const client = _jayson.default.client.http({
      port
    });

    const eslintFormatter = await this.eslint.loadFormatter(formatter);
    setInterval(() => {
      client.request("status", null, function (error, response) {
        if (error) {
          throw error;
        }

        const {
          result
        } = response;

        if (!result.message) {
          console.log(eslintFormatter.format(result.records));
          process.exit(result && (result.errorCount > 0 ? 1 : 0 || result.warningCount > maxWarnings ? 1 : 0));
        } else {
          (0, _cliUtils.clearLine)();
          process.stdout.write(result.message);
        }
      });
    }, 500);
  }

}

exports.default = Client;